# Todo

## To Do

[ ] Add support for installing a specific version of a mod
[ ] Make it so you can list the dependency's of a mod

## In Progress

## Completed

[x] Install mod dependencies - 2026-03-18
[x] Get rid of the config file (might have found a solution!) - 2026-03-17
[x] Add comments to the code - 2026-03-16
[x] Search mods from Modrinth - 2026-03-15
[x] Add logging - 2026-03-11
[x] Improve code structure - 2026-03-11
[x] List installed packages - 2026-03-10
[x] Improve command line arguments - 2026-03-07
[x] Add help message for command line arguments that do not already have them - 2026-03-07
